<?php

namespace Putup\Joblisting\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Putup\Joblisting\Http\Requests\JobListingRequest;
use Putup\Joblisting\Interfaces\JobListingRepositoryInterface;
use Putup\Joblisting\Models\JobListing;

/**
 * Admin API controller class.
 */
class JobListingAdminController extends BaseController
{
    /**
     * Initialize job_listing controller.
     *
     * @param type JobListingRepositoryInterface $job_listing
     *
     * @return type
     */
    public function __construct(JobListingRepositoryInterface $job_listing)
    {
        $this->repository = $job_listing;
        parent::__construct();
    }

    /**
     * Display a list of job_listing.
     *
     * @return json
     */
    public function index(JobListingRequest $request)
    {
        $job_listings  = $this->repository
            ->setPresenter('\\Putup\\Joblisting\\Repositories\\Presenter\\JobListingListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $job_listings['code'] = 2000;
        return response()->json($job_listings) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display job_listing.
     *
     * @param Request $request
     * @param Model   JobListing
     *
     * @return Json
     */
    public function show(JobListingRequest $request, JobListing $job_listing)
    {
        $job_listing         = $job_listing->presenter();
        $job_listing['code'] = 2001;
        return response()->json($job_listing)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new job_listing.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(JobListingRequest $request, JobListing $job_listing)
    {
        $job_listing         = $job_listing->presenter();
        $job_listing['code'] = 2002;
        return response()->json($job_listing)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new job_listing.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(JobListingRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $job_listing          = $this->repository->create($attributes);
            $job_listing          = $job_listing->presenter();
            $job_listing['code']  = 2004;

            return response()->json($job_listing)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show job_listing for editing.
     *
     * @param Request $request
     * @param Model   $job_listing
     *
     * @return json
     */
    public function edit(JobListingRequest $request, JobListing $job_listing)
    {
        $job_listing         = $job_listing->presenter();
        $job_listing['code'] = 2003;
        return response()-> json($job_listing)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the job_listing.
     *
     * @param Request $request
     * @param Model   $job_listing
     *
     * @return json
     */
    public function update(JobListingRequest $request, JobListing $job_listing)
    {
        try {

            $attributes = $request->all();

            $job_listing->update($attributes);
            $job_listing         = $job_listing->presenter();
            $job_listing['code'] = 2005;

            return response()->json($job_listing)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the job_listing.
     *
     * @param Request $request
     * @param Model   $job_listing
     *
     * @return json
     */
    public function destroy(JobListingRequest $request, JobListing $job_listing)
    {
        try {
            $t = $job_listing->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('joblisting::job_listing.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
