<?php

namespace Putup\Joblisting\Http\Controllers;
use Litepie\Joblisting\Http\Requests\JobListingRequest;
use Litepie\Joblisting\Models\JobListing;

trait JobListingWorkflow {
	
    /**
     * Workflow controller function for job_listing.
     *
     * @param Model   $job_listing
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(JobListingRequest $request, JobListing $job_listing, $step)
    {

        try {

            $job_listing->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('joblisting::job_listing.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/job_listing/job_listing/' . $job_listing->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/job_listing/job_listing/' . $job_listing->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for job_listing.
     *
     * @param Model   $job_listing
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(JobListing $job_listing, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $job_listing->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('joblisting::job_listing.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('joblisting::admin.job_listing.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('joblisting::admin.job_listing.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('joblisting::admin.job_listing.message', $data)->render();

        }

    }
}