<?php

namespace Putup\Joblisting\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Putup\Joblisting\Models\JobListing;

class JobListingAction
{
    /**
     * Perform the complete action.
     *
     * @param JobListing $job_listing
     *
     * @return JobListing
     */
    public function complete(JobListing $job_listing)
    {
        try {
            $job_listing->status = 'complete';
            return $job_listing->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param JobListing $job_listing
     *
     * @return JobListing
     */public function verify(JobListing $job_listing)
    {
        try {
            $job_listing->status = 'verify';
            return $job_listing->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param JobListing $job_listing
     *
     * @return JobListing
     */public function approve(JobListing $job_listing)
    {
        try {
            $job_listing->status = 'approve';
            return $job_listing->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param JobListing $job_listing
     *
     * @return JobListing
     */public function publish(JobListing $job_listing)
    {
        try {
            $job_listing->status = 'publish';
            return $job_listing->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param JobListing $job_listing
     *
     * @return JobListing
     */
    public function archive(JobListing $job_listing)
    {
        try {
            $job_listing->status = 'archive';
            return $job_listing->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param JobListing $job_listing
     *
     * @return JobListing
     */
    public function unpublish(JobListing $job_listing)
    {
        try {
            $job_listing->status = 'unpublish';
            return $job_listing->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
