<?php

namespace Putup\Joblisting\Workflow;

use Putup\Joblisting\Models\JobListing;
use Validator;

class JobListingValidator
{

    /**
     * Determine if the given job_listing is valid for complete status.
     *
     * @param JobListing $job_listing
     *
     * @return bool / Validator
     */
    public function complete(JobListing $job_listing)
    {
        return Validator::make($job_listing->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given job_listing is valid for verify status.
     *
     * @param JobListing $job_listing
     *
     * @return bool / Validator
     */
    public function verify(JobListing $job_listing)
    {
        return Validator::make($job_listing->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given job_listing is valid for approve status.
     *
     * @param JobListing $job_listing
     *
     * @return bool / Validator
     */
    public function approve(JobListing $job_listing)
    {
        return Validator::make($job_listing->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given job_listing is valid for publish status.
     *
     * @param JobListing $job_listing
     *
     * @return bool / Validator
     */
    public function publish(JobListing $job_listing)
    {
        return Validator::make($job_listing->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given job_listing is valid for archive status.
     *
     * @param JobListing $job_listing
     *
     * @return bool / Validator
     */
    public function archive(JobListing $job_listing)
    {
        return Validator::make($job_listing->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given job_listing is valid for unpublish status.
     *
     * @param JobListing $job_listing
     *
     * @return bool / Validator
     */
    public function unpublish(JobListing $job_listing)
    {
        return Validator::make($job_listing->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
